@@ -69,7 +69,9 @@ class AwsCliLayer(
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCliLayer.__init__)
+            def stub(scope: constructs.Construct, id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
